@@ -1006,7 +1006,7 @@ class Script(default.Script):
             oldFocus = None
 
         caretOffset = 0
-        if self.utilities.inFindToolbar(oldFocus):
+        if not oldFocus or self.utilities.inFindToolbar(oldFocus):
             newFocus, caretOffset = self.utilities.getCaretContext()
 
         if newFocus.getRole() == pyatspi.ROLE_UNKNOWN:
@@ -1594,6 +1594,11 @@ class Script(default.Script):
             debug.println(debug.LEVEL_INFO, msg, True)
             return True
 
+        if self.utilities.eventIsChromePageSwitchNoise(event):
+            msg = "WEB: Ignoring event believed to be chrome page switch noise"
+            debug.println(debug.LEVEL_INFO, msg, True)
+            return True
+
         if not self.utilities.inDocumentContent(event.source):
             msg = "WEB: Event source is not in document content"
             debug.println(debug.LEVEL_INFO, msg, True)
@@ -1614,6 +1619,11 @@ class Script(default.Script):
             debug.println(debug.LEVEL_INFO, msg, True)
             return True
 
+        if self.utilities.eventIsChromePageSwitchNoise(event):
+            msg = "WEB: Ignoring event believed to be chrome page switch noise"
+            debug.println(debug.LEVEL_INFO, msg, True)
+            return True
+
         if not self.utilities.inDocumentContent(event.source):
             msg = "WEB: Event source is not in document content"
             debug.println(debug.LEVEL_INFO, msg, True)
